3-D Large Cupcake Cake Pan by Wilton Wilton Pans
Description: 3-D Large Cupcake Cake Pan by Wilton. What fun! A giant cupcake that the whole party can share. Great for birthdays or any special occasion. Even heat distribution with easy release and clean -up. Assemble shaped top and bottom cake halves with a thin layer of icing. Finished cake 8-1/4 x 7-1/2 inches. 10 cup total capacity. Wilton Pans
Keywords: 3-D Large Cupcake Cake Pan by Wilton Wilton Pans ,

### Recommended Products

- Satin Ice Rolled Fondant Icing White 20 Pounds $56.99$47.99
- Ateco Cake Tester $1.39
- Tylose Powder by CAI $4.79
- Ultra-Moist Wedding White Cake Mix, 5 Pounds by Chef Alan Tetreault $15.99
- Buttercream Icing Vanilla 3 Pounds by Chef Alan Tetreault $9.99

rollover to zoom

# 3-D Large Cupcake Cake Pan by Wilton

- Share
- Print
- Wish List

- Availability: In Stock
- Product ID: 21785

- Our Price

- ## $30.99

- QTY

- Description
- Specifications
- Manufacturer

3-D Large Cupcake Cake Pan by Wilton.

What fun! A giant cupcake that the whole party can share. Great for birthdays or any special occasion. Even heat distribution with easy release and clean -up. Assemble shaped top and bottom cake halves with a thin layer of icing. Finished cake 8-1/4 x 7-1/2 inches. 10 cup total capacity.

Features: | 3-D
Brand: | Wilton
Design/Shape: | Cupcake
Material: | Aluminum
Dimensions: | 7-1/2 x 8-1/4 Inches

About WILTON PRODUCTS

Wilton Enterprises is the leading food crafting company in the industry. Wilton offers the industry´s most comprehensive & innovative selection of baking, cake decorating, candy making, cookie making, wedding, baby, party & seasonal supplies!